From 9172342412e585232d299450270526e2a2dae4ed Mon Sep 17 00:00:00 2001
From: Robert Haas <rhaas@postgresql.org>
Date: Fri, 7 Feb 2020 12:18:03 -0500
Subject: [PATCH v2 4/4] Move src/backend/utils/hash/hashfn.c to src/common

This also involves renaming src/include/utils/hashutils.h, which
becomes src/include/common/hashfn.h. Perhaps an argument can be
made for keeping the hashutils.h name, but it seemed more
consistent to make it match the name of the file, and also more
descriptive of what is actually going on here.
---
 contrib/citext/citext.c                            | 2 +-
 contrib/hstore/hstore_op.c                         | 2 +-
 contrib/pg_stat_statements/pg_stat_statements.c    | 2 +-
 contrib/sepgsql/uavc.c                             | 2 +-
 src/backend/access/common/tupdesc.c                | 2 +-
 src/backend/access/hash/hashfunc.c                 | 2 +-
 src/backend/access/tablesample/bernoulli.c         | 2 +-
 src/backend/access/tablesample/system.c            | 2 +-
 src/backend/commands/async.c                       | 2 +-
 src/backend/executor/execGrouping.c                | 2 +-
 src/backend/lib/bloomfilter.c                      | 2 +-
 src/backend/lib/dshash.c                           | 2 +-
 src/backend/nodes/bitmapset.c                      | 2 +-
 src/backend/nodes/tidbitmap.c                      | 2 +-
 src/backend/partitioning/partbounds.c              | 2 +-
 src/backend/storage/file/sharedfileset.c           | 2 +-
 src/backend/tsearch/ts_typanalyze.c                | 2 +-
 src/backend/utils/adt/acl.c                        | 2 +-
 src/backend/utils/adt/date.c                       | 2 +-
 src/backend/utils/adt/jsonb_gin.c                  | 2 +-
 src/backend/utils/adt/jsonb_util.c                 | 2 +-
 src/backend/utils/adt/mac.c                        | 2 +-
 src/backend/utils/adt/mac8.c                       | 2 +-
 src/backend/utils/adt/network.c                    | 2 +-
 src/backend/utils/adt/numeric.c                    | 2 +-
 src/backend/utils/adt/rangetypes.c                 | 2 +-
 src/backend/utils/adt/tid.c                        | 2 +-
 src/backend/utils/adt/uuid.c                       | 2 +-
 src/backend/utils/adt/varchar.c                    | 2 +-
 src/backend/utils/adt/varlena.c                    | 2 +-
 src/backend/utils/cache/catcache.c                 | 2 +-
 src/backend/utils/hash/Makefile                    | 1 -
 src/backend/utils/hash/dynahash.c                  | 2 +-
 src/backend/utils/resowner/resowner.c              | 2 +-
 src/common/Makefile                                | 1 +
 src/{backend/utils/hash => common}/hashfn.c        | 4 ++--
 src/include/access/hash.h                          | 2 +-
 src/include/{utils/hashutils.h => common/hashfn.h} | 6 +++---
 38 files changed, 40 insertions(+), 40 deletions(-)
 rename src/{backend/utils/hash => common}/hashfn.c (99%)
 rename src/include/{utils/hashutils.h => common/hashfn.h} (97%)

diff --git a/contrib/citext/citext.c b/contrib/citext/citext.c
index a4adafe895..df139462a6 100644
--- a/contrib/citext/citext.c
+++ b/contrib/citext/citext.c
@@ -4,9 +4,9 @@
 #include "postgres.h"
 
 #include "catalog/pg_collation.h"
+#include "common/hashfn.h"
 #include "utils/builtins.h"
 #include "utils/formatting.h"
-#include "utils/hashutils.h"
 #include "utils/varlena.h"
 
 PG_MODULE_MAGIC;
diff --git a/contrib/hstore/hstore_op.c b/contrib/hstore/hstore_op.c
index 01e59beaa3..fb1bb0681c 100644
--- a/contrib/hstore/hstore_op.c
+++ b/contrib/hstore/hstore_op.c
@@ -5,10 +5,10 @@
 
 #include "access/htup_details.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "funcapi.h"
 #include "hstore.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 
 /* old names for C functions */
diff --git a/contrib/pg_stat_statements/pg_stat_statements.c b/contrib/pg_stat_statements/pg_stat_statements.c
index e0dbeebde3..e4fda4b404 100644
--- a/contrib/pg_stat_statements/pg_stat_statements.c
+++ b/contrib/pg_stat_statements/pg_stat_statements.c
@@ -62,6 +62,7 @@
 #include <unistd.h>
 
 #include "catalog/pg_authid.h"
+#include "common/hashfn.h"
 #include "executor/instrument.h"
 #include "funcapi.h"
 #include "mb/pg_wchar.h"
@@ -77,7 +78,6 @@
 #include "tcop/utility.h"
 #include "utils/acl.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 
 PG_MODULE_MAGIC;
diff --git a/contrib/sepgsql/uavc.c b/contrib/sepgsql/uavc.c
index d3723768a6..639a52c556 100644
--- a/contrib/sepgsql/uavc.c
+++ b/contrib/sepgsql/uavc.c
@@ -14,10 +14,10 @@
 
 #include "catalog/pg_proc.h"
 #include "commands/seclabel.h"
+#include "common/hashfn.h"
 #include "sepgsql.h"
 #include "storage/ipc.h"
 #include "utils/guc.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 
 /*
diff --git a/src/backend/access/common/tupdesc.c b/src/backend/access/common/tupdesc.c
index 00bb4cb53d..28835512f0 100644
--- a/src/backend/access/common/tupdesc.c
+++ b/src/backend/access/common/tupdesc.c
@@ -23,12 +23,12 @@
 #include "access/tupdesc_details.h"
 #include "catalog/pg_collation.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "miscadmin.h"
 #include "parser/parse_type.h"
 #include "utils/acl.h"
 #include "utils/builtins.h"
 #include "utils/datum.h"
-#include "utils/hashutils.h"
 #include "utils/resowner_private.h"
 #include "utils/syscache.h"
 
diff --git a/src/backend/access/hash/hashfunc.c b/src/backend/access/hash/hashfunc.c
index 5b517106ff..a8498226e3 100644
--- a/src/backend/access/hash/hashfunc.c
+++ b/src/backend/access/hash/hashfunc.c
@@ -28,8 +28,8 @@
 
 #include "access/hash.h"
 #include "catalog/pg_collation.h"
+#include "common/hashfn.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/pg_locale.h"
 
 /*
diff --git a/src/backend/access/tablesample/bernoulli.c b/src/backend/access/tablesample/bernoulli.c
index 46016fb5de..606730d6cb 100644
--- a/src/backend/access/tablesample/bernoulli.c
+++ b/src/backend/access/tablesample/bernoulli.c
@@ -28,9 +28,9 @@
 
 #include "access/tsmapi.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "optimizer/optimizer.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 
 
 /* Private state */
diff --git a/src/backend/access/tablesample/system.c b/src/backend/access/tablesample/system.c
index 8a5f03bfd3..29b7c0d3c2 100644
--- a/src/backend/access/tablesample/system.c
+++ b/src/backend/access/tablesample/system.c
@@ -29,9 +29,9 @@
 #include "access/relscan.h"
 #include "access/tsmapi.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "optimizer/optimizer.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 
 
 /* Private state */
diff --git a/src/backend/commands/async.c b/src/backend/commands/async.c
index 9aa2b61600..dae939a4ab 100644
--- a/src/backend/commands/async.c
+++ b/src/backend/commands/async.c
@@ -126,6 +126,7 @@
 #include "access/xact.h"
 #include "catalog/pg_database.h"
 #include "commands/async.h"
+#include "common/hashfn.h"
 #include "funcapi.h"
 #include "libpq/libpq.h"
 #include "libpq/pqformat.h"
@@ -138,7 +139,6 @@
 #include "storage/sinval.h"
 #include "tcop/tcopprot.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 #include "utils/ps_status.h"
 #include "utils/snapmgr.h"
diff --git a/src/backend/executor/execGrouping.c b/src/backend/executor/execGrouping.c
index de0205f4fc..f6c3e4cbde 100644
--- a/src/backend/executor/execGrouping.c
+++ b/src/backend/executor/execGrouping.c
@@ -19,9 +19,9 @@
 #include "postgres.h"
 
 #include "access/parallel.h"
+#include "common/hashfn.h"
 #include "executor/executor.h"
 #include "miscadmin.h"
-#include "utils/hashutils.h"
 #include "utils/lsyscache.h"
 #include "utils/memutils.h"
 
diff --git a/src/backend/lib/bloomfilter.c b/src/backend/lib/bloomfilter.c
index 29b62e70e4..f040e83c01 100644
--- a/src/backend/lib/bloomfilter.c
+++ b/src/backend/lib/bloomfilter.c
@@ -35,9 +35,9 @@
 
 #include <math.h>
 
+#include "common/hashfn.h"
 #include "lib/bloomfilter.h"
 #include "port/pg_bitutils.h"
-#include "utils/hashutils.h"
 
 #define MAX_HASH_FUNCS		10
 
diff --git a/src/backend/lib/dshash.c b/src/backend/lib/dshash.c
index 5e0167d9b0..78ccf03217 100644
--- a/src/backend/lib/dshash.c
+++ b/src/backend/lib/dshash.c
@@ -31,11 +31,11 @@
 
 #include "postgres.h"
 
+#include "common/hashfn.h"
 #include "lib/dshash.h"
 #include "storage/ipc.h"
 #include "storage/lwlock.h"
 #include "utils/dsa.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 
 /*
diff --git a/src/backend/nodes/bitmapset.c b/src/backend/nodes/bitmapset.c
index f711e6c699..2719ea45a3 100644
--- a/src/backend/nodes/bitmapset.c
+++ b/src/backend/nodes/bitmapset.c
@@ -20,10 +20,10 @@
  */
 #include "postgres.h"
 
+#include "common/hashfn.h"
 #include "nodes/bitmapset.h"
 #include "nodes/pg_list.h"
 #include "port/pg_bitutils.h"
-#include "utils/hashutils.h"
 
 
 #define WORDNUM(x)	((x) / BITS_PER_BITMAPWORD)
diff --git a/src/backend/nodes/tidbitmap.c b/src/backend/nodes/tidbitmap.c
index e102589e74..ad4e071ca3 100644
--- a/src/backend/nodes/tidbitmap.c
+++ b/src/backend/nodes/tidbitmap.c
@@ -41,11 +41,11 @@
 #include <limits.h>
 
 #include "access/htup_details.h"
+#include "common/hashfn.h"
 #include "nodes/bitmapset.h"
 #include "nodes/tidbitmap.h"
 #include "storage/lwlock.h"
 #include "utils/dsa.h"
-#include "utils/hashutils.h"
 
 /*
  * The maximum number of tuples per page is not large (typically 256 with
diff --git a/src/backend/partitioning/partbounds.c b/src/backend/partitioning/partbounds.c
index 95af37b9c7..dfc2dc03cf 100644
--- a/src/backend/partitioning/partbounds.c
+++ b/src/backend/partitioning/partbounds.c
@@ -21,6 +21,7 @@
 #include "catalog/pg_inherits.h"
 #include "catalog/pg_type.h"
 #include "commands/tablecmds.h"
+#include "common/hashfn.h"
 #include "executor/executor.h"
 #include "miscadmin.h"
 #include "nodes/makefuncs.h"
@@ -32,7 +33,6 @@
 #include "utils/builtins.h"
 #include "utils/datum.h"
 #include "utils/fmgroids.h"
-#include "utils/hashutils.h"
 #include "utils/lsyscache.h"
 #include "utils/partcache.h"
 #include "utils/ruleutils.h"
diff --git a/src/backend/storage/file/sharedfileset.c b/src/backend/storage/file/sharedfileset.c
index 6666a25521..f7206c9175 100644
--- a/src/backend/storage/file/sharedfileset.c
+++ b/src/backend/storage/file/sharedfileset.c
@@ -22,11 +22,11 @@
 
 #include "catalog/pg_tablespace.h"
 #include "commands/tablespace.h"
+#include "common/hashfn.h"
 #include "miscadmin.h"
 #include "storage/dsm.h"
 #include "storage/sharedfileset.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 
 static void SharedFileSetOnDetach(dsm_segment *segment, Datum datum);
 static void SharedFileSetPath(char *path, SharedFileSet *fileset, Oid tablespace);
diff --git a/src/backend/tsearch/ts_typanalyze.c b/src/backend/tsearch/ts_typanalyze.c
index 24c6479f61..2eed0cd137 100644
--- a/src/backend/tsearch/ts_typanalyze.c
+++ b/src/backend/tsearch/ts_typanalyze.c
@@ -16,9 +16,9 @@
 #include "catalog/pg_collation.h"
 #include "catalog/pg_operator.h"
 #include "commands/vacuum.h"
+#include "common/hashfn.h"
 #include "tsearch/ts_type.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 
 
 /* A hash key for lexemes */
diff --git a/src/backend/utils/adt/acl.c b/src/backend/utils/adt/acl.c
index cc4170efbf..bce1f1e0b1 100644
--- a/src/backend/utils/adt/acl.c
+++ b/src/backend/utils/adt/acl.c
@@ -26,6 +26,7 @@
 #include "commands/dbcommands.h"
 #include "commands/proclang.h"
 #include "commands/tablespace.h"
+#include "common/hashfn.h"
 #include "foreign/foreign.h"
 #include "funcapi.h"
 #include "lib/qunique.h"
@@ -34,7 +35,6 @@
 #include "utils/array.h"
 #include "utils/builtins.h"
 #include "utils/catcache.h"
-#include "utils/hashutils.h"
 #include "utils/inval.h"
 #include "utils/lsyscache.h"
 #include "utils/memutils.h"
diff --git a/src/backend/utils/adt/date.c b/src/backend/utils/adt/date.c
index 393ee991b0..0c55b68fbf 100644
--- a/src/backend/utils/adt/date.c
+++ b/src/backend/utils/adt/date.c
@@ -21,6 +21,7 @@
 #include <time.h>
 
 #include "access/xact.h"
+#include "common/hashfn.h"
 #include "libpq/pqformat.h"
 #include "miscadmin.h"
 #include "nodes/supportnodes.h"
@@ -29,7 +30,6 @@
 #include "utils/builtins.h"
 #include "utils/date.h"
 #include "utils/datetime.h"
-#include "utils/hashutils.h"
 #include "utils/sortsupport.h"
 
 /*
diff --git a/src/backend/utils/adt/jsonb_gin.c b/src/backend/utils/adt/jsonb_gin.c
index 72a88121d5..63122edf2e 100644
--- a/src/backend/utils/adt/jsonb_gin.c
+++ b/src/backend/utils/adt/jsonb_gin.c
@@ -63,9 +63,9 @@
 #include "access/stratnum.h"
 #include "catalog/pg_collation.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "miscadmin.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/jsonb.h"
 #include "utils/jsonpath.h"
 #include "utils/varlena.h"
diff --git a/src/backend/utils/adt/jsonb_util.c b/src/backend/utils/adt/jsonb_util.c
index edec657cd3..04b70c805b 100644
--- a/src/backend/utils/adt/jsonb_util.c
+++ b/src/backend/utils/adt/jsonb_util.c
@@ -15,11 +15,11 @@
 
 #include "catalog/pg_collation.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "common/jsonapi.h"
 #include "miscadmin.h"
 #include "utils/builtins.h"
 #include "utils/datetime.h"
-#include "utils/hashutils.h"
 #include "utils/json.h"
 #include "utils/jsonb.h"
 #include "utils/memutils.h"
diff --git a/src/backend/utils/adt/mac.c b/src/backend/utils/adt/mac.c
index f9eb0b57d8..8aeddc6863 100644
--- a/src/backend/utils/adt/mac.c
+++ b/src/backend/utils/adt/mac.c
@@ -13,12 +13,12 @@
 
 #include "postgres.h"
 
+#include "common/hashfn.h"
 #include "lib/hyperloglog.h"
 #include "libpq/pqformat.h"
 #include "port/pg_bswap.h"
 #include "utils/builtins.h"
 #include "utils/guc.h"
-#include "utils/hashutils.h"
 #include "utils/inet.h"
 #include "utils/sortsupport.h"
 
diff --git a/src/backend/utils/adt/mac8.c b/src/backend/utils/adt/mac8.c
index 571eee920f..b7b2968b92 100644
--- a/src/backend/utils/adt/mac8.c
+++ b/src/backend/utils/adt/mac8.c
@@ -21,9 +21,9 @@
 
 #include "postgres.h"
 
+#include "common/hashfn.h"
 #include "libpq/pqformat.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/inet.h"
 
 /*
diff --git a/src/backend/utils/adt/network.c b/src/backend/utils/adt/network.c
index a6dd8b75aa..0ab54316f8 100644
--- a/src/backend/utils/adt/network.c
+++ b/src/backend/utils/adt/network.c
@@ -15,6 +15,7 @@
 #include "access/stratnum.h"
 #include "catalog/pg_opfamily.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "common/ip.h"
 #include "lib/hyperloglog.h"
 #include "libpq/libpq-be.h"
@@ -26,7 +27,6 @@
 #include "utils/builtins.h"
 #include "utils/fmgroids.h"
 #include "utils/guc.h"
-#include "utils/hashutils.h"
 #include "utils/inet.h"
 #include "utils/lsyscache.h"
 #include "utils/sortsupport.h"
diff --git a/src/backend/utils/adt/numeric.c b/src/backend/utils/adt/numeric.c
index c92ad5a4fe..bd00f23b94 100644
--- a/src/backend/utils/adt/numeric.c
+++ b/src/backend/utils/adt/numeric.c
@@ -27,6 +27,7 @@
 #include <math.h>
 
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "common/int.h"
 #include "funcapi.h"
 #include "lib/hyperloglog.h"
@@ -38,7 +39,6 @@
 #include "utils/builtins.h"
 #include "utils/float.h"
 #include "utils/guc.h"
-#include "utils/hashutils.h"
 #include "utils/int8.h"
 #include "utils/numeric.h"
 #include "utils/sortsupport.h"
diff --git a/src/backend/utils/adt/rangetypes.c b/src/backend/utils/adt/rangetypes.c
index 639e1dad6c..b95132b714 100644
--- a/src/backend/utils/adt/rangetypes.c
+++ b/src/backend/utils/adt/rangetypes.c
@@ -31,12 +31,12 @@
 #include "postgres.h"
 
 #include "access/tupmacs.h"
+#include "common/hashfn.h"
 #include "lib/stringinfo.h"
 #include "libpq/pqformat.h"
 #include "miscadmin.h"
 #include "utils/builtins.h"
 #include "utils/date.h"
-#include "utils/hashutils.h"
 #include "utils/int8.h"
 #include "utils/lsyscache.h"
 #include "utils/rangetypes.h"
diff --git a/src/backend/utils/adt/tid.c b/src/backend/utils/adt/tid.c
index fad2057754..4ce8375eab 100644
--- a/src/backend/utils/adt/tid.c
+++ b/src/backend/utils/adt/tid.c
@@ -25,12 +25,12 @@
 #include "access/tableam.h"
 #include "catalog/namespace.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "libpq/pqformat.h"
 #include "miscadmin.h"
 #include "parser/parsetree.h"
 #include "utils/acl.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/rel.h"
 #include "utils/snapmgr.h"
 #include "utils/varlena.h"
diff --git a/src/backend/utils/adt/uuid.c b/src/backend/utils/adt/uuid.c
index 4abd861dd7..c906ee789d 100644
--- a/src/backend/utils/adt/uuid.c
+++ b/src/backend/utils/adt/uuid.c
@@ -13,12 +13,12 @@
 
 #include "postgres.h"
 
+#include "common/hashfn.h"
 #include "lib/hyperloglog.h"
 #include "libpq/pqformat.h"
 #include "port/pg_bswap.h"
 #include "utils/builtins.h"
 #include "utils/guc.h"
-#include "utils/hashutils.h"
 #include "utils/sortsupport.h"
 #include "utils/uuid.h"
 
diff --git a/src/backend/utils/adt/varchar.c b/src/backend/utils/adt/varchar.c
index 1e1239a1ba..39acfdff6c 100644
--- a/src/backend/utils/adt/varchar.c
+++ b/src/backend/utils/adt/varchar.c
@@ -17,13 +17,13 @@
 #include "access/detoast.h"
 #include "catalog/pg_collation.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "libpq/pqformat.h"
 #include "mb/pg_wchar.h"
 #include "nodes/nodeFuncs.h"
 #include "nodes/supportnodes.h"
 #include "utils/array.h"
 #include "utils/builtins.h"
-#include "utils/hashutils.h"
 #include "utils/lsyscache.h"
 #include "utils/pg_locale.h"
 #include "utils/varlena.h"
diff --git a/src/backend/utils/adt/varlena.c b/src/backend/utils/adt/varlena.c
index 1b351cbc68..0d7baacca1 100644
--- a/src/backend/utils/adt/varlena.c
+++ b/src/backend/utils/adt/varlena.c
@@ -20,6 +20,7 @@
 #include "access/detoast.h"
 #include "catalog/pg_collation.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "common/int.h"
 #include "lib/hyperloglog.h"
 #include "libpq/pqformat.h"
@@ -29,7 +30,6 @@
 #include "regex/regex.h"
 #include "utils/builtins.h"
 #include "utils/bytea.h"
-#include "utils/hashutils.h"
 #include "utils/lsyscache.h"
 #include "utils/memutils.h"
 #include "utils/pg_locale.h"
diff --git a/src/backend/utils/cache/catcache.c b/src/backend/utils/cache/catcache.c
index 64776e3209..3613ae5f44 100644
--- a/src/backend/utils/cache/catcache.c
+++ b/src/backend/utils/cache/catcache.c
@@ -24,6 +24,7 @@
 #include "catalog/pg_collation.h"
 #include "catalog/pg_operator.h"
 #include "catalog/pg_type.h"
+#include "common/hashfn.h"
 #include "miscadmin.h"
 #ifdef CATCACHE_STATS
 #include "storage/ipc.h"		/* for on_proc_exit */
@@ -32,7 +33,6 @@
 #include "utils/builtins.h"
 #include "utils/datum.h"
 #include "utils/fmgroids.h"
-#include "utils/hashutils.h"
 #include "utils/inval.h"
 #include "utils/memutils.h"
 #include "utils/rel.h"
diff --git a/src/backend/utils/hash/Makefile b/src/backend/utils/hash/Makefile
index fc7b165f7f..d4c1210e36 100644
--- a/src/backend/utils/hash/Makefile
+++ b/src/backend/utils/hash/Makefile
@@ -14,7 +14,6 @@ include $(top_builddir)/src/Makefile.global
 
 OBJS = \
 	dynahash.o \
-	hashfn.o \
 	pg_crc.o
 
 include $(top_srcdir)/src/backend/common.mk
diff --git a/src/backend/utils/hash/dynahash.c b/src/backend/utils/hash/dynahash.c
index d245e1aa12..b5381958e7 100644
--- a/src/backend/utils/hash/dynahash.c
+++ b/src/backend/utils/hash/dynahash.c
@@ -86,10 +86,10 @@
 #include <limits.h>
 
 #include "access/xact.h"
+#include "common/hashfn.h"
 #include "storage/shmem.h"
 #include "storage/spin.h"
 #include "utils/dynahash.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 
 
diff --git a/src/backend/utils/resowner/resowner.c b/src/backend/utils/resowner/resowner.c
index ac6f226f59..3c39e48825 100644
--- a/src/backend/utils/resowner/resowner.c
+++ b/src/backend/utils/resowner/resowner.c
@@ -20,12 +20,12 @@
  */
 #include "postgres.h"
 
+#include "common/hashfn.h"
 #include "jit/jit.h"
 #include "storage/bufmgr.h"
 #include "storage/ipc.h"
 #include "storage/predicate.h"
 #include "storage/proc.h"
-#include "utils/hashutils.h"
 #include "utils/memutils.h"
 #include "utils/rel.h"
 #include "utils/resowner_private.h"
diff --git a/src/common/Makefile b/src/common/Makefile
index ab98f4faaf..ce01df68b9 100644
--- a/src/common/Makefile
+++ b/src/common/Makefile
@@ -54,6 +54,7 @@ OBJS_COMMON = \
 	exec.o \
 	f2s.o \
 	file_perm.o \
+	hashfn.o \
 	ip.o \
 	jsonapi.o \
 	keywords.o \
diff --git a/src/backend/utils/hash/hashfn.c b/src/common/hashfn.c
similarity index 99%
rename from src/backend/utils/hash/hashfn.c
rename to src/common/hashfn.c
index ecc52014af..990f18e610 100644
--- a/src/backend/utils/hash/hashfn.c
+++ b/src/common/hashfn.c
@@ -10,7 +10,7 @@
  *
  *
  * IDENTIFICATION
- *	  src/backend/utils/hash/hashfn.c
+ *	  src/common/hashfn.c
  *
  * NOTES
  *	  It is expected that every bit of a hash function's 32-bit result is
@@ -23,7 +23,7 @@
  */
 #include "postgres.h"
 
-#include "utils/hashutils.h"
+#include "common/hashfn.h"
 
 
 /*
diff --git a/src/include/access/hash.h b/src/include/access/hash.h
index 9fc0696096..2707e1924b 100644
--- a/src/include/access/hash.h
+++ b/src/include/access/hash.h
@@ -21,10 +21,10 @@
 #include "access/itup.h"
 #include "access/sdir.h"
 #include "catalog/pg_am_d.h"
+#include "common/hashfn.h"
 #include "lib/stringinfo.h"
 #include "storage/bufmgr.h"
 #include "storage/lockdefs.h"
-#include "utils/hashutils.h"
 #include "utils/hsearch.h"
 #include "utils/relcache.h"
 
diff --git a/src/include/utils/hashutils.h b/src/include/common/hashfn.h
similarity index 97%
rename from src/include/utils/hashutils.h
rename to src/include/common/hashfn.h
index ba3ecb7592..6ecc864f84 100644
--- a/src/include/utils/hashutils.h
+++ b/src/include/common/hashfn.h
@@ -4,8 +4,8 @@
  * Portions Copyright (c) 2017-2020, PostgreSQL Global Development Group
  */
 
-#ifndef HASHUTILS_H
-#define HASHUTILS_H
+#ifndef HASHFN_H
+#define HASHFN_H
 
 
 /*
@@ -101,4 +101,4 @@ murmurhash32(uint32 data)
 	return h;
 }
 
-#endif							/* HASHUTILS_H */
+#endif							/* HASHFN_H */
-- 
2.21.1 (Apple Git-122.3)

